"""
Packager source package Apport hook
"""
import os, subprocess
import apport
import apport.hookutils as hook

def add_info(report, hook_ui=None):
    """
    Add log file if exists
    """
    # Report bugs to launchpad project directly
    if not apport.packaging.is_distro_package(report['Package'].split()[0]):
        report['ThirdParty'] = 'True'
        report['CrashDB'] = 'packager'

    if hook_ui:
        # Add packager configuration file
        hook.attach_file_if_exists(report,
                                   os.path.expanduser('~/.packager.cfg'),
                                   'packager.cfg')

        options = hook_ui.ui.options
        if options.directory:
            # Add debian files
            hook.attach_file_if_exists(report,
                                       os.path.join(options.directory, 'debian', 'changelog'),
                                       'DebianChangelog')
            hook.attach_file_if_exists(report,
                                       os.path.join(options.directory, 'debian', 'control'),
                                       'DebianControl')

            # Add branch information
            process = subprocess.Popen(['bzr', 'info'],
                                       cwd=options.directory,
                                       stdout=subprocess.PIPE)
            stdout, _ = process.communicate()
            report['BzrInfo'] = stdout

        # Add log file passed through the command line
        hook.attach_file_if_exists(report, options.log_filename, 'packager.log')
