"""
Abstract packager interface

This interface should be inherited by all classes
that implement a packager interface
"""
import os

from . import build

class PackagerInterface(object):
    DESCRIPTION = ('packager is a tool to make it possible to upload '
                   'debian packages from an application under development '
                   'to multiple series and/or PPAs in launchpad.')

    DEBIAN_FILES = ['debian/changelog', 'debian/control']
    DODO_FILE = os.path.join(os.path.dirname(__file__),
                             'dodo.py')

    BUILD = 'Packager - {version}'.format(version=build.version)


class PackagerException(Exception):
    """
    Exception used to display custom text
    in the exception handler instead of the traceback.
    """
    def __init__(self, message, detailed_message=''):
        self.message = message
        self.detailed_message = detailed_message

    def __str__(self):
        message = [self.message]
        if self.detailed_message:
            message.append(self.detailed_message)

        return '\n\n'.join(message)
