"""
Command line parsing functions
"""
import argparse

class Parser(argparse.ArgumentParser):
    def __init__(self, build, description, options=None):
        super(Parser, self).__init__(description=description)
        self.add_argument('-v', '--version', action='version',
                          version=build,
                          help='Display version and exit')
        subparsers = self.add_subparsers(title='subcommands', dest='subcommand',
                                         parser_class=argparse.ArgumentParser)

        subcommand_data = (('source', 'Create source package'),
                           ('render', 'Render template files'),
                           ('upload', 'Upload source package to launchpad'),
                           ('binary', 'Create binary packages'),
                           ('install', 'Install binary packages'),
                           ('clean', 'Clean packaging files'),
                           ('config', 'Show/Set/Remove configuration variables'),
                           ('info', 'Display project information'),
                           ('help', 'Show help message as when using -h option'),
                           )

        def get_config_parser(self, parser):
            subparsers = parser.add_subparsers(title='subcommands', dest='config_subcommand')
            subparser = subparsers.add_parser('show',
                                              help='Show configuration variables for the current project')
            subparser.add_argument('-d', '--default', action='store_true',
                                   help='Show only default variables')

            subparser = subparsers.add_parser('set',
                                              help='Set configuration variable (either current project or defaults)')
            subparser.add_argument('-d', '--default', action='store_true',
                                   help='Set default variable (current project by default)')
            subparser.add_argument('name', help='Variable name')
            subparser.add_argument('value', help='Variable value')

            subparser = subparsers.add_parser('remove',
                                              help='Remove configuration variable for the curent project')
            subparser.add_argument('-d', '--default', action='store_true',
                                   help='Set default variable')
            subparser.add_argument('name', help='Variable name')


        def append_default(help_string, option):
            if options:
                help_string += ' (currently set to: {0!r})'.format(options[option])
            return help_string

        for subcommand, description in subcommand_data:
            subparser = subparsers.add_parser(subcommand,
                                              description=description,
                                              help=description)


            if subcommand == 'config':
                get_config_parser(self, subparser)
            elif subcommand == 'upload':
                help_string = append_default('Make the packages available for these '
                                             'distributions', 'distros')
                subparser.add_argument('-d', '--distro', nargs='+', dest='distros',
                                       metavar='DISTRO', help=help_string)
                help_string = append_default('Upload the packages to these PPAs', 'ppas')
                subparser.add_argument('-p', '--ppa', nargs='+', dest='ppas',
                                       metavar='PPA', help=help_string)
                subparser.add_argument('-t', '--tag', action='store_true',
                                       help='Tag branch after uploading source package')
            elif subcommand == 'help':
                subparser.add_argument('command',
                                       nargs='?',
                                       default = None,
                                       help=('Subcommand for which the help is required. '
                                             "Main help printed if this isn't supplied or the command "
                                             'is unknown'))


    def parse_args(self, args):
        """Parse command line"""
        args = super(Parser, self).parse_args()
        args.subparsers = next(action
                               for action in self._actions
                               if isinstance(action, argparse._SubParsersAction)).choices
        return args
