#!/usr/bin/python
"""
Apply changes needed to satisfy build dependencies
"""
import sys, argparse
import apt.cache

def main(args):
    """
    Install/delete packages
    """
    cache = apt.cache.Cache()
    if args.install:
        for package_name in args.install:
            package = cache[package_name]
            if not package.is_installed:
                package.mark_install(False)
    if args.delete:
        for package_name in args.delete:
            package = cache[package_name]
            if package.is_installed:
                package.mark_delete(False)

    committed = cache.commit()
    return 0 if committed else 1


if __name__ == '__main__':
    parser = argparse.ArgumentParser(__doc__)
    parser.add_argument('-i', '--install', nargs='+', metavar='PACKAGE',
                        help='Packages to be installed')
    parser.add_argument('-d', '--delete', nargs='+', metavar='PACKAGE',
                        help='Packages to be deleted')
    args = parser.parse_args()
    sys.exit(main(args))
